from zs_utils.email.templates.oms import base

icon = "payment_remind_icon.png"

subject_ru = "Привязка банковской карты"

title_ru = "Привязка банковской карты"

body_ru = "Пользователь {name} (email: {email}) привязал карту {card_number}"

cheers_ru = base.cheers_team_email_ru
