from zs_utils.email.templates.oms import base

icon = "icon_email.png"

title_ru = "Переезд фулфилмента на новый домен"

body_ru = """
<p>Здравствуйте, {first_name}!</p>

<p>Благодарим Вас за использование фулфилмента ZoneSmart. Хотели бы сообщить о важном изменении в работе:</p>

<p><b>С 00:00 часов 13 мая 2024 г. по Московскому времени фулфилмент ZoneSmart будет доступен только по адресу <a href="https://app.zonesmart.com">app.zonesmart.com</a>.</b><br>
Домен app.zonesmart.ru больше с этого момента не будет поддерживаться.</p>

<h3>Что это означает для Вас</h3>
<ol>
<li>Никаких изменений в работе сервиса не произойдет, Вы сможете пользоваться личным кабинетом используя те же учетные данные (email и пароль), что и раньше.</li>
<li>Вся ваша информация (товары, остатки, заказы, интеграции и тд.) на момент 00:00 часов 13 мая 2024 г. будет перенесена на новый домен.</li>
<li>Все заказы, поступившие через домен app.zonesmart.ru до 00:00 часов 13 мая 2024 г. будут обработаны в обычном режиме.</li>
<li>Если вы использовали для оплаты услуг фулфилмента иностранную карту через Stripe, дополнительных действий не требуется. Если же вы использовали карту российского банка, необходимо совершить действие из списка ниже.</li>
</ol>

<h3>Какие действия требуются от Вас</h3>
<ol>
<li>Если вы вносили заказы вручную, то с 00:00 часов 13 мая 2024 г. это нужно будет исключительно через домен <a href="https://app.zonesmart.com">app.zonesmart.com</a>.</li>
<li><b>Если вы использовали для оплаты услуг фулфилмента и доставки карту российского банка — ее необходимо привязать заново на новом домене.</b> Для этого перейдите в раздел <a href="https://app.zonesmart.com/payment"><b>Платежи -> Платежная информация -> Добавить карту</a>.</b><br>
Вся платежная информация с домена app.zonesmart.ru будет удалена.</li>
</ol>

<p>В случае возникновения ошибок при переносе данных или иных проблем просьба обращаться в <a href="https://app.zonesmart.com/support/tickets">службу поддержки в личном кабинете</a>.</p>

<p>С уважением,<br>
Ваша команда ZoneSmart</p>
"""

cheers_ru = base.cheers_team_email_ru
cheers_en = base.cheers_team_email_en
